/*
 * Software Suspend header file.
 *
 * This file sets the major and minor version numbers of the version specific
 * part of the Software Suspend patch. The major and minor numbers must match
 * those of the core patch. The extra is updated as necessary for version
 * specific changes.
 * 
 * It also contains the macros to be used for compiling the core code
 * under this kernel version.
 */

#ifndef SWSUSP_VERSION_SPECIFIC_REVISION
#define SWSUSP_VERSION_SPECIFIC_REVISION 0x201
#define SWSUSP_VERSION_SPECIFIC_REVISION_STRING "2.0.0"

#if defined(CONFIG_FBCON_SPLASHSCREEN)
#include <linux/fb.h>
#include <video/fbcon.h>

static inline struct splash_data * get_splash_data(int consolenr)
{
	extern struct display fb_display[MAX_NR_CONSOLES];

	BUG_ON(consolenr >= MAX_NR_CONSOLES);

	return fb_display[consolenr].splash_data;
}
#else
#include <linux/console_struct.h>
#endif

extern asmlinkage ssize_t sys_write(unsigned int fd, const char * buf, size_t count);
#define NUM_CPUS smp_num_cpus
#define MAX(a,b)	((signed long)(a)>(signed long)(b)?(a):(b))
#define MIN(a,b)	((signed long)(a)<(signed long)(b)?(a):(b))
#define PROCESS_SIG_MASK(p) &p->sigmask_lock
#define RECALC_SIGPENDING recalc_sigpending(current)
#define FOR_EACH_THREAD_TASK_STRUCTS *p
#define FOR_EACH_THREAD_START for_each_task(p)
#define FOR_EACH_THREAD_END
#define THREAD_PREEMPT_COUNT current->preempt_count
#define WAKE_UP(p) signal_wake_up(p)
#define FREE_AREA_TYPE free_area_t
#define ZONE_TYPE zone_t
#ifdef CONFIG_SOFTWARE_SUSPEND2
#define STORAGE_UNSUSPEND storage_unsuspend();
#else
#define STORAGE_UNSUSPEND
#endif
#define STORAGE_SUSPEND storage_suspend();
#define EAT_MEMORY_FLAGS GFP_ATOMIC
extern void storage_unsuspend(void);
#define CPU0_MASK (1 << cpu_logical_map(0))

#define INACTIVE_LIST_FOR_EACH(procedure) \
do { \
 if (nr_inactive_pages) { \
  struct list_head * entry = inactive_list.prev; \
   while (entry != &inactive_list) { \
    struct page * page; \
    page = list_entry(entry, struct page, lru); \
    procedure(page); \
    entry = entry->prev; \
   } \
 } \
} while(0)

#define ACTIVE_LIST_FOR_EACH(procedure) \
do { \
 if (nr_active_pages) { \
  struct list_head * entry = active_list.prev; \
   while (entry != &active_list) { \
    struct page * page; \
    page = list_entry(entry, struct page, lru); \
    procedure(page); \
    entry = entry->prev; \
   } \
 } \
} while(0)

#endif
